A function to impute twins in the simulated pedigree data.frame.
Twins can be imputed by specifying their IDs or by specifying the generation the twin should be imputed.
This is a supplementary function for simulatePedigree.
Usage
makeTwins(
ped,
ID_twin1 = NA_integer_,
ID_twin2 = NA_integer_,
gen_twin = 2,
verbose = FALSE,
zygosity = "MZ",
twin_sex = "R"
)Arguments
- ped
A
data.framein the same format as the output ofsimulatePedigree.- ID_twin1
A vector of
IDof the first twin.- ID_twin2
A vector of
IDof the second twin.- gen_twin
A vector of
generationof the twin to be imputed.- verbose
logical. If TRUE, print progress through stages of algorithm
- zygosity
A character string indicating the zygosity of the twins. Default is "MZ" for monozygotic twins.
- twin_sex
A character string indicating the sex of the twins. Default is randomly assigned ("R"). If specified, it should be either "M" or "F"