Add a paternal-line descendant flag to a pedigree
Source:R/addParentalChain.R
addPaternalLineFlag.RdAdds a logical flag indicating whether a specified anchor individual appears anywhere in each person's ordered paternal ancestor chain.
Arguments
- ped
A pedigree data frame containing a parental chain list-column.
- anchor_id
ID of the anchor individual to search for within each person's parental chain.
- flag_col
Character string giving the name of the logical output column to add to `ped`.
- chain_col
Character string giving the name of the list-column containing ordered parental ancestor chains.